package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`"``!````@"(```````!``````````!"Y````
M````!P``($``.``+`$``'P`>``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```!0I@``````
M`%"F````````4*8````````/``````````\``````````0`````````#``!P
M!````*@"````````J`(```````"H`@```````!@`````````&``````````(
M``````````$````%````````````````````````````````````+*X`````
M```LK@```````````0```````0````8```#PKP```````/"O`0``````\*\!
M``````#8`P```````"`4```````````!```````"````!````.@$````````
MZ`0```````#H!````````)`"````````D`(````````(``````````0````$
M````H`0```````"@!````````*`$````````1`````````!$``````````0`
M````````4.5T9`0```!@I@```````&"F````````8*8````````$`0``````
M``0!````````!`````````!1Y71D!P``````````````````````````````
M```````````````````````````0`````````%+E=&0$````\*\```````#P
MKP$``````/"O`0``````$``````````0``````````$`````````````````
M````````````````````````````````````````````````````````"```
M``````````,``@(``0````````0``0`````````!*````````/8'`+(`````
M`````````````````````&`P`@```````2@`````````````````````````
M``````````````!@,`(```````$H````````````````````````````````
M````````8#`"```````!*`````````0``+(`````````````````````````
M`&`P`@```````2@```````!\``&R``````````````````````````!@,`(`
M``````$H````````_/__\P``````````````````````````8#`"```````!
M*````````'``/[(``````````````````````````&`P`@```````2@`````
M``"$``"R``````````````````````````!@,`(```````$H````````<```
ML@``````````````````````````8#`"```````!*````````'```+(`````
M`````````````````````&`P`@```````2@`````````````````````````
M``````````````!@,`(```````$H````````````L```````````````````
M````````8#`"```````$````%`````,```!'3E4`<A7+!]&SBJJFT'4UQ0`_
MBGP&JL4$````$`````$```!'3E4```````,````$```````````````!````
M`````&,#`````````0````````!N`P````````$`````````?@,````````!
M`````````(@#````````#P`````````;!0````````P`````````X!\`````
M```-`````````*!G````````&0````````#PKP$``````!L`````````"```
M```````:`````````/BO`0``````'``````````(``````````0`````````
M>`<````````%`````````)@6````````!@````````!X#`````````H`````
M````.04````````+`````````!@`````````-0``<`````!XJ@$``````!4`
M```````````````````#`````````'"P`0``````$0````````!0'0``````
M`!(`````````H``````````3`````````!```````````0``<``````!````
M``````4``'```````@`````````&``!P````````````````"@``<``````B
M`````````!$``'``````;``````````2``!P`````!X`````````$P``<```
M```D`````````!@```````````````````#[__]O``````$```@`````_O__
M;P````"P'````````/___V\``````P````````#P__]O`````-(;````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-(```!L```````````````%`````@``
M``<`````````/P```%L`````````20```#P`````````2@``````````````
M````````````````9@```#T```!J`````````$0`````````+P``````````
M````````````````````:P````````!=`````````!T`````````````````
M`````````````",````U`````````#@`````````````````````````)0``
M`&<````H````````````````````````````````````"P``````````````
M0P````````````````````8`````````.0````````!!````1@```#``````
M```````````````2```````````````D`````````%``````````.@``````
M``!,`````````"X````K````5P```%X`````````````````````````````
M`$4````````````````````````````````````````````````````>````
M(0`````````R````#``````````6````6````&@````````````````````.
M`````````!L````<``````````T````L````-P```````````````````!``
M````````)P```%4````V`````````&,````B````9````#$`````````````
M`````````````````!<````#````)@```````````````````&``````````
M`````!$````8```````````````*````.P```````````````````#X```!`
M````6@```````````````````!H``````````````"T```!3`````````$@`
M`````````````"D````/````````````````````90``````````````5```
M`!,``````````````````````````````%P`````````60```%$```!B````
M4@```!4``````````````#0````@``````````````````````````0`````
M````30```$(```!I````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````%\`````````1P``````````````````````````````
M`````````````````````!0````J````2P````````!6````````````````
M```````````````?```````````````S`````````!D`````````````````
M`````````````````````````````&$````(````````````````````3P``
M````````````````````````````````````````````3@``````````````
M````````````````````````````````````````````````````````````
M``````````D`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````,`#`#@'P``````````````````
MH`,``!(`#0`(8P````````@`````````DP0``!(`#0!42````````#0`````
M`````0```!,`\?\!````````````````````K00``"``%@``L`$`````````
M````````A````!$`````````````````````````"P0``!(`#0#D3@``````
M`$@`````````AP0``!(`#0!(4````````+``````````I`0``!``&0#(LP$`
M````````````````\`,``!(`#0#@2@```````"P`````````Y`,``!(`#0`,
M2P```````"P!````````<`0``!(`#0`050```````.0(````````3@0``!(`
M#0"`40```````%`!````````JP0``!``%@``L`$`````````````````/0``
M`!$`$`#09P````````0`````````N`0``!``%@``L`$`````````````````
MS@,``!(`#0!<1P```````/@`````````$@```!$`%P!@L`$`````````````
M````D`,``!(`#0!@8@```````*@`````````?00``!$`%@!0L`$```````@`
M````````OP0``!``&@`0Q`$`````````````````8P0``!(`#0`X3```````
M`#`"````````600``!(`#0#04@```````$`"````````Q`0``!``&@#(LP$`
M````````````````L`,``!(`#0"$1@```````%@`````````*0```!(`#0`@
M(````````&`"````````T`0``!(`#0"`(@``````````````````.`0``!(`
M#0"(2````````%@"````````)@0``!(`#0`L3P```````!P!````````A0``
M`"$`````````````````````````_0,``!(`#0!H3@```````'P`````````
MV`0``!``#0`@(```````````````````WP0``!``&@#(LP$`````````````
M````100``!(`#0#X4````````(@`````````N`,``!(`#0#T70```````&P$
M````````S````!(```"`9P``````````````````G0```!(```!P9P``````
M````````````M@```!(```!@9P``````````````````C`$``!(```!09P``
M````````````````:````!(```!`9P``````````````````/0,``!(````P
M9P``````````````````7@```!(````@9P``````````````````A@```!$`
M````````````````````````C@```!(````09P``````````````````M0(`
M`"``````````````````````````:@$``!(`````9P``````````````````
MI0```!(```#P9@``````````````````N@$``!(```#@9@``````````````
M````E0(``!(```#09@``````````````````[`$``!(`````````````````
M````````AP(``!(```#`9@``````````````````%@$``!(```"P9@``````
M````````````E@```!(```"@9@``````````````````I`(``!(```"09@``
M````````````````G`$``!(```"`9@``````````````````)`$``!(```!P
M9@``````````````````>P(``!(```!@9@``````````````````S@$``!(`
M``!09@``````````````````Z@```!(```!`9@``````````````````4@$`
M`!(````P9@``````````````````IP$``!(`````````````````````````
M3`$``!(````@9@``````````````````10$``!(````09@``````````````
M````.P(``!(`````9@``````````````````9@(``!(```#P90``````````
M````````,0,``!(```#@90``````````````````>`$``!(```#090``````
M````````````'````!(```#`90``````````````````Q0```!(```"P90``
M````````````````&@(``!(```"@90``````````````````#P$``!(```"0
M90``````````````````0`$``!(```"`90``````````````````%P,``"(`
M````````````````````````^0(``!(```!P90``````````````````7P(`
M`!(```!@90``````````````````\0```!(```!090``````````````````
M4P(``!(```!`90```````````````````0$``!(````P90``````````````
M````?P$``!(````@90``````````````````3````!(````090``````````
M````````PP$``!(`````90``````````````````*0(``!(```#P9```````
M````````````ZP(``!(```#@9```````````````````X0```!(```#09```
M````````````````1@(``!$`````````````````````````#`(``!(```#`
M9```````````````````V@```!(```"P9```````````````````)@,``!$`
M````````````````````````,@$``!(```"@9```````````````````<P``
M`!(```"09```````````````````D@$``!(```"`9```````````````````
M_0$``!(```!P9```````````````````OP```!(```!@9```````````````
M````W`$``!(`````````````````````````"0,``!(```!09```````````
M````````40,``!$`````````````````````````"`$``!(```!`9```````
M````````````'0$``!(````P9```````````````````EP$``!(````@9```
M````````````````^0```!(````09```````````````````8P$``!$`````
M````````````````````'00``!(`````9```````````````````SP(``"``
M````````````````````````AP$``!(```#P8P``````````````````+@``
M`"(`````````````````````````KP```!(```#@8P``````````````````
M.0$``!(```#08P```````````````````%]$64Y!34E#7TQ)3DM)3D<`7U]2
M3$1?34%0`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I;F%L:7IE`%])3U]S
M=&1I;E]U<V5D`%]?<F5G:7-T97)?871F;W)K`%]?>'-T870V-`!?7VQX<W1A
M=#8T`%]?<W1A8VM?8VAK7V9A:6P`7U]E;G9I<F]N`'-T<FYC;7``86-C97-S
M`&]P96YD:7(`<F5A9&1I<C8T`'-T<F-M<`!C;&]S961I<@!R;61I<@!S=')L
M96X`7U]S<')I;G1F7V-H:P!U;FQI;FL`<F5A9&QI;FL`;65M8VAR`')E86QL
M;V,`;65M;6]V90!G971P:60`;65M8W!Y`'-T<F-H<@!S=')T;VL`<W1R9'5P
M`%]?<W1R;F-P>5]C:&L`9V5T=6ED`'-T<G-T<@!E>&ET`&UE;7-E=`!M:V1I
M<@!?7V5R<FYO7VQO8V%T:6]N`'-T9&5R<@!?7V9P<FEN=&9?8VAK`&]P96XV
M-`!L<V5E:S8T`')E860`8VQO<V4`<&5R;%]F<F5E`'!E<FQ?<&%R<V4`4&5R
M;%]A=&9O<FM?=6YL;V-K`'!E<FQ?<G5N`'!E<FQ?86QL;V,`4&5R;%]S>7-?
M=&5R;0!B;V]T7T1Y;F%,;V%D97(`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O
M;G-T<G5C=`!P97)L7V1E<W1R=6-T`%!E<FQ?<WES7VEN:70S`%!E<FQ?<W9?
M,G!V7V9L86=S`%!E<FQ?;F5W6%,`4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L
M7V%V7V9E=&-H`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?;F5W6%-?9FQA9W,`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`4&5R;%]A=E]S
M:&EF=`!?7V=M;VY?<W1A<G1?7P!03%]T:')?:V5Y`%!E<FQ?9V5T7W-V`'!T
M:')E861?9V5T<W!E8VEF:6,`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS
M;P!L:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD+G-O+C$`7U]L:6)C7V-S
M=5]I;FET`%]?;&EB8U]C<W5?9FEN:0!X<U]I;FET`%A37TEN=&5R;F%L<U]0
M05)?0D]/5`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<&%R
M7V)A<V5N86UE`'!A<E]E;G9?8VQE86X`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'-H85]I;FET
M`'-H85]U<&1A=&4`<VAA7V9I;F%L`'!A<E]I;FET7V5N=@!P87)?;6MT;7!D
M:7(`;7E?<&%R7W!L`'!A<E]C;&5A;G5P`'!A<E]C=7)R96YT7V5X96,`7V5D
M871A`%]?9&%T85]S=&%R=`!?9F1A=&$`7V5N9`!?7V)S<U]S=&%R=`!?7W-T
M87)T`%]F=&5X=`!?9F)S<P!'3$E"0U\R+C``1TQ)0D-?,BXT`$=,24)#7S(N
M,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N,@`O=7-R+VQI8B]P97)L-2]C;W)E
M7W!E<FPO0T]210````````$``0`!``$``@`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``@`!``$``0`!``$`!P`"``(`
M`@`#``@``P`"``(````'``,````````````"``(```````<```````(``@``
M``(``@`````````#``(``@````(``@```````@`"`````@`#``8`````````
M`@```````@````(`!0```````@``````!``"``(``@`"``(``@````(``P`"
M``(``````````0`!`&X#```0````(````!!I:0T```@`Y00````````!``$`
MB`,``!`````@````%&EI#0``!`#O!`````````$`!0!^`P``$`````````!T
M&6D)```'`/D$```0````<AEI"0``!@`%!0``$````!1I:0T```4`[P0``!``
M```2:6D-```#`!$%```0````$&EI#0```@#E!```````````````````````
M``````#PKP$``````````````!(#^*\!```````````````2`Q"P`0``````
M````````$@,8L`$``````````````!(#(+`!```````````````2`RBP`0``
M````````````$@,PL`$``````````````!(#4+`!```````````````2`\"S
M`0``````````````$@,`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````\/^]9P``O/\"`!P\+>"9`P@`O_^`$)QG2(*"WP0`
M0!``````2(*9WPGX(`,`````"`"_WP``O-\(`.`#$`"]9[#_O6=``+S_`@`<
M/!``I?\0`*5G+>"9`P@`IO\(`*9G'`"DKQP`I&=`$)QG2`"__R``L/\P@IG?
M.`"S_S``LO\H`+'_"?@@`\""D-_H@8;?D(&$W^"`F=^E$!$$)2C``*B"@M\`
M`$*0$P!`%$B!F=^(@IG?"?@@`R4((``E($``.(""WP0`@!3HLT3\0(*9WPGX
M(`,!``0DX(*9WPGX(`,E""``2(&9WPGX(`,```2.F0I`H$B!F=\)^"`#```$
MC@``!(Y(@9G?Z@1#D`(`8S0)^"`#Z@1#H!P`I(_J!$.0:(*9WP4`A"0!`&,T
M^"`$``GX(`/J!$.@$`"EWP0``R0<`*:/)3A``#B`@M\`M$?\``"BW```XOQ0
M@(+?H&E"9`@`XOSH@(+?``!"W!``XOQ0@(+?J&E"9!@`XOPX@(+?^+-#K"48
M```!`&-D`!`#`"H@1@`[`(`4^"`#`#B`D=\#`,(D)4```%"`A=\#`,8DN(&9
MW_@0`@`M$.(`Z+,DWMQ&I60)^"`#``!`_`4`0!0E@$``@(&9WPGX(`/HLR3>
M)8!``+""F=_HLR3>"?@@`U"`D]]0@(3?1#]S9B7(8`)8!Q$$R&B$9!``0!38
M@IG?.("2W_"S0MX'`$!4\+-$WE"`A-\ER&`"3@<1!%!HA&3PLT+^\+-$W@,`
M@!#P@)G?B0L1!"4((`#8@IG?"?@@`^BS)-[0@9G?"?@@`R4((`!(`+_?)1``
M`D``O-\X`+/?,`"RWR@`L=\@`+#?"`#@`U``O6<#`$(D+2"D`/@0`@```(3<
M+1#B`+O_`!```$3\)0#@`P$`$00`````)<B``P(`'#S4#9PG+>"?`R7X```@
M@(3?``"EWP@`IF?P_P$D).BA`RB`A]\P@(C?)4A``"50H`,@@IG?"?@@`P``
M``#__P`0`````````````````@`#/"T8>0"`#6-D.(!DW$"`8MQHL(1D!0!$
M$#B#>=P#`"`3)0@@``@`(`,E""``"`#@`R4((``"``8\+3#9`$@-QF0X@,3<
M0(#"W&BPA&0O$$0`^Q@"`/XO`@`M**,`>R@%``4`H!!H@=G<`P`@$R4((``(
M`"`#)0@@``@`X`,E""``X/^]9Q``O/\"`!P\&`"__RW@F0,(`+#__`R<9SB`
M@M_0LT.0#0!@%"6`0`!(@X+?!`!`$$B`@M](@YG?"?@@`P``1-Q0@)G?X"(Y
M9\O_$00E""```0`")-"S`J(8`+_?$`"\WP@`L-\(`.`#(`"]9P(``CPM$%D`
MC`Q"9%"`6=P8(SEGR_\`$"4((`!`_;UG.`"'9'@`BV3_``D\L`*\_P(`'#RX
M`K__+>"9`Z@"L_^@`K+_<`R<9Y@"L?^0`K#_`(.*WP``0MV(`J+_"`"B9R5`
M0````.7<"`#G9!``"&4X'@4`.#(%`#P8`P`D,,D`/A@#`"489@`Z,@4``/_&
M,"489@`Z-@4`_P#&,"489@`^,`4`\/\#_3X:!0`^+@4``/]C,"4890`X+@8`
M.#(&`#PH!0`D,,D`/B@%`"4890`E&&8`X_]G%?C_`_T``D9D0`!%W`@`0F1@
M`$/<)AAE``@`1=PF&&4`^/]%W"8890!X*`,`^A\#`"48HP`\&`,`/A@#`/+_
M1A1X`$/\``",W():#3P@`(O<F7FM91``A]P8`(C<"`")W/H>#`!X$0P`)1!#
M``@`H]\\$`(`N#<)`#X0`@`M&&T`+1AK`"T00P`F&.@`)!AI`"88:``M$$,`
MNA@)`"4PPP`0`*/?/!`"`#R`!@`^$`(`/H`0`'@I`@`M&&T`)L#P`"T8:``D
MP`P#)L`'`RW``P/Z'@(`)2BC`+H8#``MP`4#N"\,`"4HHP`\P!@`)G#%`!@`
MIM\^P!@`/,@%`"1PP@%X&1@`/L@9`"9PT`$M,,T`+3#'`"UPQ@'Z-A@`)1AF
M`"UPPP&X'P(`NA`"`#QP#@`E$&(`/G`.`"88H@`@`*7?/'@"`/HV#@`D&'@`
M/G@/`"88>0`M**T`+8"P`'@I#@`M&'``)2BF`+B'#@`M&&4`N"\8`+K`&``\
M&`,`)2BX`"@`N-\^&`,`)A!%`#PP!0`D$$X`NG`.`"W`#0,^,`8`)A!/`"6`
M#@(MR!D#>,$#`"8HL``\<!``+1!9`/K.`P`D**,`/G`.`"7`&0.XSP,`)BBF
M`"T06``P`+C?/!`"`#X0`@`MP`T#+7@/`_K&`@`M**\`>'D"`"5X^`$X`+C?
M+2BO`+IX`P`ER"\#/"@%`"W`#0,F&!D"/B@%`"TP!@,\>!D`)!AB`/K&!0`^
M>`\`)AAN`"T89@!X,04`)3#8`+C'`@`M&&8`NC`"`"7`!@,\&`,`)A`X`T``
MN=\^&`,`/#`8`"0010`^,`8`)A!/`"W(+0,M<"X#^LX#`"T03@!X<0,`)7#9
M`;C/!0`M$$X`NG`%`"7(+@,\$`(`)B@9`T@`N-\^$`(`/'`9`"0HHP`^<`X`
M)BBF`"W`#0,M>`\#^L8"`"THKP!X>0(`)7CX`;C'`P`M**\`NG@#`"7`#P,\
M*`4`)A@X`U``N=\^*`4`/'@8`"088@`^>`\`)AAN`"W(+0,M,"8#^LX%`"T8
M9@!X,04`)3#9`+C/`@`M&&8`NC`"`"4P)@,\&`,`)A`&`U@`N-\^&`,`/(`&
M`"0010"XSP,`/H`0`"803P`MP`T#+7`.`_K&`P`M$$X`>'$#`"5PV`$M$$X`
MN'<%`+HH!0`\$`(`)7#%`6``I=\^$`(`)C#.`#S`#@`D,,,`NA@#`"THK0`^
MP!@`)C#0`"7((P-H`*/?+7BO`'@I`@`F<-D!+3#/`/I^`@`D<,(!)2BO`"T8
M;0`F<-@!/'@9`"TPQ0`M@'``/G@/`#PP!@`M<-`!/C`&`/HN!@!X&08`)1AE
M`"UPPP&X'P(`NA`"`#QP#@`E$&(`<`"CWSYP#@`FR"(#/(`"`/HN#@`DR"8#
M/H`0`"T8;0`FR"\#+<!X`'@9#@`MR#@#)1AE`+HH!@`MR",#N!\&`"4H90`\
MR!D`)C!%`'@`HM\^R!D`/,`%`"0PS@#Z'AD`/L`8`"8PT``M$$T`+7A/`'@1
M&0`M,,\`)1!#`+@?#@"Z<`X`+3#"`(``HM\E&&X`/#`&`"8HHP`\>`,`/C`&
M`"T030`D*+D`^G8&`#YX#P`M@%``)BBX`'@1!@`M*+``)1!.`(@`KM\M**(`
MN!<9`+K(&0`\*`4`)1!9`"UPS0$^*`4`)AAB`"W`V`%X<04`/(`"`"089@`^
M@!``)AAO`"T8>`#ZQ@4`)7#8`9``N-\M&&X`N'<&`+HP!@`\&`,`)3#&`2W`
M#0,^&`,`)A!&`"UX#P/ZQ@,`/'`&`"0010`^<`X`)A!0`"T03P!X>0,`)7CX
M`2T03P"X?P4`NB@%`#P0`@`E*.4!F`"OWSX0`@`F,,4`/)`%`'C!`@`D,,,`
M/I`2`"UX[0$F,,X`+8#P`?I^`@`EP`\#N'\#`+H8`P`M,-``/,`8`"48XP&@
M`*_?/L`8`"8HHP`M,-@`)"BB`#S(!@`M:.T!L`"OWR8HL@`^R!D`+6BN`?IV
M&0`M:*T`>"D9`+B/&0"ZR!D`)2BN`"6(.0(\*`4`/B@%`"UHI0&X+P(`NA`"
M`#R8#0`E$*(`V6X%/#Z8$P`FP&(`H>NE-/IV$P`\&`,`)L`&`Z@`IM\M>.4!
M/A@#`+C/$P`\P!@`+7CC`28840`^P!@`/!`"`"TPQ0`F:&T`/A`"`"V0T@!X
M,1,`/&@-`+J8$P`E,,X`+<`2`SYH#0`ER#,#/#`&`"UX[0$^,`8`+<`&`[@`
MIM\\D!@`/I`2`"TPQ0#Z'A(`>&D2`"TPP@`F$#D")6BC`3R($0`FP%@`/&@-
M`#Z($0`\P!@`/F@-`#[`&``M>.T!P`"MWRTPV`"XQQ(`/(`/`+J0$@`^@!``
M)<`2`RUHI0'Z%A``>'$0`"UHL0&XCQ``)7#"`280.`.Z@!``/,@9`#QP#@`F
M>$\`)8@P`C[(&0`^<`X`/'@/`"TPS@`^>`\`R`"NWSR8!@`M:*\!/I@3`"UP
MQ0'Z%A,`>!D3`"UPV0&XSQ,`)1AB`"80$0.ZF!,`/,`8`#P8`P`F,$8`)<@S
M`S[`&``^&`,`/#`&`"UHHP$^,`8`/)`-`"UPQ@$^D!(`^AX2`'@1$@"X?Q(`
MNI`2`"400P#0`*/?)7CR`3P0`@`^$`(`+1AE`"UPP@$F$#D"+1AX`#R($0`\
M@`X`)FA-`#Z($0`^@!``/&@-`/H6$`!X,1``/F@-`"4PP@#8`*+?+1AM`#PP
M!@`^,`8`+1!%`"T89@`F,"\#+1!1`+B/$``\P`,`)G#.`+J`$``\R!D`/L`8
M`#QP#@`EB#`"/L@9`/HV&`!X:1@`/G`.`"5HI@'@`*;?+1!.`#QH#0`^:`T`
M+3#%`"T030`F:/$!+3#9`+C/&``F&*,!/)`"`.@`K=^ZP!@`/'@/`#P8`P`^
MD!(`)<@X`SYX#P`^&`,`>'$2`"UHI0$M,,,`^AX2`"UHKP&X?Q(`)7##`288
M.0*ZD!(`/(@1`#QP#@`F$&(`)7CR`3Z($0`^<`X`/!`"`"TPS@`^$`(`\`"N
MWSR`!@`M:*(!/H`0`"UPQ0'Z%A``>!D0`"UPT0&XCQ``)1AB`"80+P.Z@!``
M/,@9`#P8`P`F,$8`)8@P`C[(&0`^&`,`/#`&`"UHHP$^,`8`/,`-`"UPQ@$^
MP!@`^AX8`'@1&`"XAQ@`NL`8`"400P#X`*/?)8`8`CP0`@`^$`(`+1AE`"UP
MP@$F$/$!+1AY`#QX#P`\D`X`)FA-`#YX#P`^D!(`/&@-`/H6$@!X,1(`/F@-
M`"4PP@```:+?+1AM`#PP!@`^,`8`+1!%`"T89@`F,#`"+1!/`+A_$@`\F`,`
M)G#.`+J0$@`\B!$`/I@3`#QP#@`E>/(!/H@1`/HV$P!X:1,`/G`.`"5HI@$(
M`:;?+1!.`#QH#0`^:`T`+3#%`"T030`F:`\"+3#1`+B/$P`F&*,!/,@"`!`!
MK=^ZF!,`/(`0`#P8`P`^R!D`)8@S`CZ`$``^&`,`>,$9`"UHI0$M,,,`^AX9
M`"UHL`&XAQD`)<`#`R88\0&ZR!D`/'@/`#S`&``F$&(`)8`9`CYX#P`^P!@`
M/!`"`"TPV``^$`(`&`&XWSR0!@`M:*(!/I`2`"W`!0/Z%A(`>!D2`"W`#P.X
M?Q(`)1AB`"80,`*ZD!(`/(@1`#P8`P`F,$8`)7CR`3Z($0`^&`,`/#`&`"UH
MHP$^,`8`(`&CWSR8#0`MP`8#/I@3`"T890#Z%A,`>'$3`"T8<0"XCQ,`)7#"
M`280#P*ZF!,`/(`0`#QP#@`F:$T`)8@S`CZ`$``^<`X`/&@-`"W`#@,^:`T`
M*`&NWSS(&``M&&T`/L@9`"UPQ0'Z%AD`>#$9`"UPT`&XAQD`)3#"`"80\0&Z
MR!D`/'@/`#PP!@`FP%@`)8`9`CYX#P`^,`8`/,`8`"T89@`^P!@`/)`#`"UP
MV`$^D!(`^C82`'@1$@`E$$8`,`&FWSP0`@`^$`(`+3#%`"UPP@$F$#`"+3#/
M`+A_$@`F&$,`/,`.`+J0$@`\B!$`/!@#`#[`&``E>/(!/H@1`#X8`P!X$1@`
M+3##`/H>&``E$$,`)A@/`CR`$``\$`(`)G!N`#Z`$``^$`(`/'`.`"TPP@`X
M`:+?/G`.`#S(!@`^R!D`+1!%`/IN&0!X&1D`+1!1`+B/&``E&&T`NL`8`"T0
M3@`EB#@"+1!#`#S`$0`\<`(`0`&BWS[`&``^<`X`^AX.`"TH10`F$/$!/'@/
M`"8P1@`M*+``>!$.`#YX#P`\,`8`)1!#`+@?&0`^,`8`NL@9`"THI@`E&'D`
M2`&FWRTHH@#&(P(\/,@#`"5H(P(W[T(T/"@%`#[(&0`D:*X!N!`"`#XH!0`D
MB#D"+3#"`"5HL0$M>,\`>#$%`"UHKP'Z?@4`)3#/`"UHI@&X-PX`NG`.`#QH
M#0`E<,X`/F@-`"48;@`D,-D!/'@.`"0890`^>`\`)1AF`%`!IM\M,,(`+<#8
M`'@Q#0`M&'@`^L8-`"4PV``M&&8`N#<%`+HH!0`\&`,`)2C%`#X8`P`\P`4`
M)3#%`3[`&``D,,T`)'#8`24PS@!8`:[?+7#"`2W(V0%X<0,`+3#9`/K.`P`E
M<-D!N,\-`+IH#0`M,,X`)<@M`SPP!@`E*+D`)&@X`SXP!@`\<!D`)"BC`#YP
M#@`E**T`8`&MWRUHH@$M>*\!>&D&`"THKP#Z?@8`)6BO`2THK0"X;P,`NA@#
M`#PH!0`E&*,!/B@%`#QX`P`E:",#/G@/`"1HI@$DR"\#)6BY`6@!N=\MR"(#
M+<`X`_K.!0`M:+@!>,$%`"7`&0.XSP8`NC`&`"UHN`$ER"8#/&@-`"48>0`D
M,"\#/F@-`#S`&0`D&&4`/L`8`"489@!P`:;?+3#"`"UPS@!X,0T`+1AN`/IV
M#0`E,,X`+1AF`+@W!0"Z*`4`/!@#`"4HQ0`^&`,`/'`%`"4P)0,^<`X`)##-
M`"3(+@,E,-D`>`&YWRW((@,M>"\#^LX#`"TPSP!X>0,`)7CY`;C/#0"Z:`T`
M+3#/`"7(+0,\,`8`)2BY`"1H+@,^,`8`/'@9`"0HHP`^>`\`)2BM`(`!K=\M
M:*(!+<"X`7AI!@`M*+@`^L8&`"5HN`$M**T`N&\#`+H8`P`\*`4`)1BC`3XH
M!0`\P`,`)6@C`S[`&``D:*8!),@X`R5HN0&(`;G?+<@B`RUP+@/ZS@4`+6BN
M`7AQ!0`E<-D!N,\&`+HP!@`M:*X!)<@F`SQH#0`E&'D`)#`X`SYH#0`\<!D`
M)!AE`#YP#@`E&&8`D`&FWRTPP@`M>,\`>#$-`"T8;P#Z?@T`)3#/`"T89@"X
M-P4`NB@%`#P8`P`E*,4`/A@#`#QX!0`E,"4#/G@/`"0PS0`DR"\#)3#9`)@!
MN=\MR"(#+<`X`_K.`P`M,-@`>,$#`"7`&0.XSPT`NF@-`"TPV``ER"T#/#`&
M`"4HN0`D:"\#/C`&`#S`&0`D**,`/L`8`"4HK0"@`:W?+6BB`2UPK@%X:08`
M+2BN`/IV!@`E:*X!+2BM`+AO`P"Z&`,`/"@%`"48HP$^*`4`/'`#`"5H(P,^
M<`X`)&BF`23(+@,E:+D!J`&YWRW((@,M>"\#^LX%`"UHKP%X>04`)7CY`;C/
M!@"Z,`8`+6BO`27()@,\:`T`)1AY`"0P+@,^:`T`/'@9`"0890`^>`\`)1AF
M`+`!IM\M,,(`+<#8`'@Q#0`M&'@`^L8-`"4PV``M&&8`N#<%`+HH!0`\&`,`
M)2C%`#X8`P`\P`4`)3`E`S[`&``D,,T`),@X`R4PV0"X`;G?+<@B`RUP+@/Z
MS@,`+3#.`'AQ`P`E<-D!N,\-`+IH#0`M,,X`)<@M`SPP!@`E*+D`)&@X`SXP
M!@`\<!D`)"BC`#YP#@`E**T`P`&MWRUHH@$M>*\!>&D&`"THKP#Z?@8`)6BO
M`2THK0"X;P,`NA@#`#PH!0`E&*,!/B@%`#QX`P`E:",#/G@/`"1HI@$DR"\#
M)6BY`<@!N=\MR"(#+<`X`_K.!0`M:+@!>,$%`"7`&0.XSP8`NC`&`"UHN`$E
MR"8#/&@-`"48>0`D,"\#/F@-`#S`&0`D&&4`/L`8`"489@#0`:;?+3#"`"UP
MS@!X,0T`+1AN`/IV#0`E,,X`+1AF`+@W!0"Z*`4`/!@#`"4PQ0`^&`,`/(`&
M`"4H)@,^@!``)"BM`"1P,`,E**X`V`&NWRUPP@$M>,\!^G8#`"UXKP!X*0,`
M)2BN`#PH!0`^*`4`+7CE`;@O#0"Z:`T`/,@/`"5HK0`^R!D`)3#-`"0HL`'Z
MGAD`>'$9`"0PPP`\B`T`)7#3`24PQ0#@`:7?/H@1`#QP#@`^<`X`+1"B`"T0
M6`"XQP,`NA@#`"T0P@#H`:;?)1@#`_@!N-\MF$X`,64"/"8HHP'K8$)D/)`3
M`"8HKP"X?QD`>!`"`#Z0$@`\*`4`NL@9`"TPP@#Z;A(`/B@%`"5X^0$M@-``
M>#$2`"9P;P"XSQ(`)3#-`"THL``F<-,!NI`2`#PP!@`\&`,`/'`.`"7(,@,^
M,`8`+<`"`SYP#@`^&`,`+2BF`/`!IM\MP`,#)ACY`3R`!0`\>`\`)BAE`#Z`
M$``^>`\`+3#"`#PH!0#Z;A``+8C1`'@Q$``^*`4`)3#-`"UPT0$M*`4#N(\0
M`#PP!@"Z@!``/C`&`"6(,`(M<,8!``*FWSR8#@`^F!,`+3#"`/H>$P!X:1,`
M+3#/`+A_$P`E:*,!)A@Q`[J8$P`\R!D`/&@-`"9P;@`E>/,!/L@9`#YH#0`\
M<`X`+2BM`#YP#@`\D`4`+3#.`#Z0$@#Z;A(`>!D2`+C'$@"ZD!(`)1AM``@"
MK=\EP!(#/!@#`#X8`P`M:*(!+3##`"88+P(M:+D!/(@1`"8H90`\@`8`/H@1
M`#PH!0`^@!``/B@%`'@9$``M:*4!^BX0`"4890`0`J7?/!@#`#X8`P`M**(`
M+6BC`288^`$M*+$`N(\0`#S(#0`F,&8`NH`0`#QX#P`^R!D`/#`&`"6(,`(^
M>`\`^AX9`'AQ&0`^,`8`)7##`1@"H]\M**8`)C`1`SQP#@`\P!@`)FC-`#YP
M#@`^P!@`+1AB`#QH#0`M**X`(`*NWRT8;P`^:`T`/)`%`+A_&0`M&&T`NL@9
M`#Z0$@`E>/D!+7#"`?IN$@!X,1(`+7#8`;C'$@`E,,T`NI`2`#PP!@`EP!(#
M/C`&`"T89@`F,"\"/(@1`"8HQ0`\@`,`*`*FWSZ($0`\*`4`/H`0`#XH!0!X
M:1``+3#"`+B7$``M<,4!^BX0`"TPT0"Z@!``)6BE`28H^`$ED%`"/'@/`#QH
M#0`F&*,`/G@/`#YH#0`\&`,`+7#-`3X8`P`P`JW?/,@.`"TPPP`^R!D`+6BB
M`?H>&0!X*1D`+6BO`;B'&0`E**,`)A@2`[K(&0`\P!@`/"@%`"9P;@`E@!D"
M/L`8`#XH!0`\<`X`+3#%`#YP#@`\F`8`+6BN`3Z8$P#Z+A,`>!D3`"4890`X
M`J7?/!@#`#X8`P`M**(`+6BC`2884`(M*+@`N,<3`#R(#0`F,&8`NI@3`#R0
M$@`^B!$`/#`&`"7`$P,^D!(`^AX1`'AY$0`^,`8`)7CC`4`"H]\M**8`)C`8
M`CQX#P`\@!``)FC-`#YX#P`^@!``+1AB`#QH#0`M**\`2`*OWRT8<@`^:`T`
M/,@%`+B7$0`M&&T`NH@1`#[(&0`ED%$"+7CB`?IN&0!X,1D`+7CP`;B'&0`E
M,,T`NL@9`#PP!@`E@!D"/C`&`"T89@`F,!(#/,`8`"8HQ0`\F`,`4`*FWS[`
M&``\*`4`/I@3`#XH!0!X<1,`+3#"`"UXY0'Z+A,`+3#8`+C'$P`E<,4!)BA0
M`KJ8$P`\D!(`/'`.`"88HP`EP!,#/I`2`#YP#@`\&`,`+7CN`3X8`P!8`J[?
M/(@/`"TPPP`^B!$`+7#"`?H>$0!X:1$`+7#2`;B7$0`E:*,!)A@8`KJ($0`\
M@!``/&@-`"9X;P`ED%$"/H`0`#YH#0`\>`\`+3#-`#YX#P!@`JW?/,@&`"UP
MSP$^R!D`+6BB`?H>&0!X*1D`+6BP`;B'&0`E**,`)A@2`[K(&0`\P!@`/"@%
M`"8P9@`E@!D"/L`8`#XH!0`\,`8`+7#%`3XP!@!H`J7?/)@.`"UHI@$^F!,`
M+2BB`/H>$P!X>1,`+2BX`+C'$P`E>.,!)AA0`KJ8$P`\D!(`/'@/`"9P;@`E
MP!,#/I`2`#YX#P`\<`X`+6BO`3YP#@!P`J_?/(@-`"THK@`^B!$`+7CB`?HV
M$0!X&1$`+7CR`2489@`\&`,`/A@#`"THHP`F&!@"/(`0`#S(!0`F:&T`/H`0
M`#[(&0`\:`T`^C89`'@9&0`^:`T`)1AF`+@W$0"ZB!$`+7CM`3P8`P`E,-$`
M/A@#`"9P!@,\P!@`+7CC`7@"H]\F*,4!/L`8`#QH#P`\*`4`/F@-`"T88@`^
M*`4`^G8-`"T8<``M&&4`>"D-`"4HK@"X=QD`NL@9`"T890"``J7?)7#9`3P8
M`P`^&`,`+1"B`"8HS@`M<,@!+3#+`"9XKP`M$$P`>"D#`/IF`P`\>`\`+1!8
M`"4HK``M&&D`/G@/`#QP#@`\&`,`/#`&`"T03P`^<`X`/A@#`#XP!@`M$$4`
M&`"._`@`@_P\$`(`B`*CWR``AOP^$`(```""_+@7#0"Z:`T`)1!-`"TX1P``
M`$+=/#@'`#XX!P`$`&(0$`"'_-""F=\)^"`#)0@@`+@"O]^P`KS?J`*SWZ`"
MLM^8`K'?D`*PWP@`X`/``KUGL/^]9T``O/\"`!P\$`"Q_R6(```MX)D#2`"_
M_S@`MO\4\IQG,`"U_R@`M/\@`+/_&`"R_R``@!`(`+#_6(&"WP``5-P<`(`2
M)9B``"6HH``E,(``/0`#)```PH`B`$`4+X#3`"60@`(]`!8D`(`0````4=X0
M`"`28(&9WR4P``(E*&`""?@@`R4@(`+X_T!4"`!29BT0,`(``$*`]/]65`@`
M4F8OD%0"`0`09ON0$@`MB#`"``"RKD@`O]\E$"`"0`"\WS@`MM\P`+7?*`"T
MWR``L]\8`++?$`"QWP@`L-\(`.`#4`"]9][_0U`O@-,`V?\`$`$`QF30_[UG
M(`"\_P(`'#P$`*5G&`"P_RW@F0,H`+__'/&<9P"#D-]0@)G?```"WDP^.6<(
M`*+_M/\1!"4((``(`*3?```#W@0`@Q`H`+_?T(*9WPGX(`,E""``(`"\WQ@`
ML-\(`.`#,`"]9[#_O6=``+S_`@`</"@`L?\MX)D#(`"P_S@`L_^T\)QG,`"R
M_Q0`LF=(`+__`(.1WU"`D-]8@9/?```BWDP^$&88`*+_)2A``B7(``*4_Q$$
M"`"D_P@`0!0(`*3?&`"CWP``(MX-`&(02`"_W]""F=\)^"`#)0@@`!0`HH_X
M&`(```!BWBT00P`(`$/<[?]@$```0_S\_P`0"`!"9$``O-\X`+/?,`"RWR@`
ML=\@`+#?"`#@`U``O6<`_[UG\`"\_P(`'#PE**`#Z`"Q_RW@F0/@`+#_)8"`
M`/@`O__\[YQG`(.1WUB`F=\``"+>V`"B_[P($00E""``#@!`5"40```@`*./
M`$`%)`#P8S`$`&40)2!@``"@`S0&`(,4)0@@`*B!F=\"``4D"?@@`R4@``(!
M`$(LV`"DWP``(]X$`(,0^`"_W]""F=\)^"`#)0@@`/``O-_H`+'?X`"PWP@`
MX`,``;UGH/Z]9T@!O/\"`!P\.`&V_RW@F0-8`;__4`&^_U#OG&=``;?_,`&U
M_P"#EM\H`;3_(`&S_Q@!LO\0`;'_"`&P_P``PM[X`*+_(0"`$"4((````(*`
M'@!`$"6`@``H@9G?"?@@`R4((``9`$`0)8A``%"`DM\@`*)G__\7)%"`D]\`
M0!XD4("4WU"`E=\(`*+_V&=29N!G<V;H9Y1F$$&B9A``HO]X@9G?"?@@`R4@
M(`(.`$`44(.9WS"!F=\)^"`#)2`@`NB"F=\)^"`#)2```O@`H]\``,+>/0!B
M$%@!O]_0@IG?"?@@`R4((``3`%5D)2A``@GX(`,E(*`"ZO]`$'B!F=]0@YG?
M)2A@`@GX(`,E(*`"Y/]`$'B!F=\H@IG?"?@@`R4@``(H@IG?)2"@`@GX(`,8
M`*+_&`"CWUB"F=\M$&(``"`"``GX(`,"`(0D((&9WR5(H`(E0``")3B``B4@
M0`#__P8D&`"B_PGX(`,!``4D&`"DWV"`F=\P"!$$"`"EWPT`XA(8`*3?0`"B
MCP#P0C`*`%Y4N(*9WQ``N=\)^"`#)0@@`!B#F=\)^"`#&`"DW[S_`!!X@9G?
MN(*9WPGX(`,8`*3_]_\`$"4((`!0`;[?2`&\WT`!M]\X`;;?,`&UWR@!M-\@
M`;/?&`&RWQ`!L=\(`;#?"`#@`V`!O6>P[[UG_P\&)$`0O/\"`!P\,!"T_RW@
MF0,8$+'_)8B``#@0M?]0[9QG*!"S_P@`LV<@$++_)9"@``"#E-\E*&`"4("$
MWZ""F=]($+__$!"P_P``@M[P9X1DP(*5WP@0HO\)^"`#)0@@```0`@`@`$`8
M)8!``/__0R00$*1G__]")"T@@@#X[X2`!`"`%-B!F=\7`$`0)8!@`-B!F=\E
M,``"+P`%)`GX(`,E(&`"$`!`$$B!F=\)^"`#``"DCHB!F=\E.``")3!@`B4H
M(`()^"`#)2!```@0H]\``(+>#@!B$$@0O]_0@IG?"?@@`R4((`!(@9G?"?@@
M`P``I(Z8@IG?)3!``B4H(`()^"`#)2!``/#_`!`E""``0!"\WS@0M=\P$+3?
M*!"SWR`0LM\8$+'?$!"PWP@`X`-0$+UGH/^]9U``O/\"`!P\,`"S_RW@F0,@
M`+'_)8B``!@`L/\E@*``%.R<9U@`O_](`+;_`(.3WT``M?\X`+3_*`"R_P``
MHX```&+>"`"B_ST``B0!`&)0`0"P9"B"F=\)^"`#)2```E"`F=\$`*5G)2`@
M`DP^.6=B_A$$):!``!,`0!`ED$``*(*9WPGX(`,E($``*Q!4`"8`0!0E&"`"
M```"@@$`$&8!`%)F_/]`%/__0J((`*/?``!BWE4`8A!8`+_?T(*9WPGX(`,E
M""``6(&5WR60`````+;>)1#``@``0]P]`&`4"`!"9#B`@M\"`$0FX+-#C#H`
M8!#X(`0`8(*9WR4H@``)^"`#)2#``NC_0!```*+^`0!")O@8`@```*+>+1!#
M````0/P$`+*O)1@@`CT`!"0``&*`!`!`$`0`LH_\_T14`0!C9`0`LH\O&'$`
M`@"$9EB!E=]8@IG?`!@#`"T@@P#X$!(```"RW@GX(`,MD$("SO]`$```0OX$
M`**//0`%)/@8`@```*+>+1!#````0MP``"."`0`Q9B4@0``!`$)D`P!@$/__
M0Z#Z_V54```C@CT``R0``(.@```#@@$`$&8!`$)D_/]@%/__0Z"W_P`0)0@@
M`,#_`!`!`%(F6(*9WP$``R0)^"`#X+-#K*__0!`E($``((.9W_@P$@`)^"`#
M)2C``L+_`!```*+^4`"\WT@`MM]``+7?.`"TWS``L]\H`++?(`"QWQ@`L-\(
M`.`#8`"]9_#_O6<``+S_`@`</`@`O_\MX)D#W.F<9\""@M](@9G?"?@@`P``
M1(QH@(??4("%WP""F=\E($``\(*&WSBFYV0)^"`#`&BE9`@`O]\``+S?"`#@
M`Q``O6?@_[UG$`"\_P(`'#P(`+#_+>"9`Q@`O_^$Z9QGP(*0WTB!F=\)^"`#
M```$CG"`F=_=_Q$$)2!``$B!F=\)^"`#```$CE"`B-\E2```4("%W["!F=\E
M($``>("&WZ!K"&4@:*5D"?@@`R4X``$8`+_?$`"\WP@`L-\(`.`#(`"]9Z#?
MO6=0(+S_`@`</$@@LO\MX)D#6""__S@@L/\$Z9QG0""Q_P"#DM]P@IG?``!"
MWB@@HO\)^"`#)0@@`"`0I&=0@(G?`1`&)`$`!210@(??)4!``""!F=\(`*3_
M.&@I90GX(`-`:.=D"`"DWQ@`I6>@@IG?`!`&)`GX(`,``*7_`(`"``X```8E
M(```6(*9WP$`!"8)^"`#)8@``@@`0!`E($``"(.9WR4P``()^"`#``"EWRV(
M40`E($`````@HB@@H]\``$+>!`!B$%@@O]_0@IG?"?@@`R4((``E$(``4""\
MWT@@LM]`(+'?.""PWP@`X`-@(+UG\/^]9P``O/\"`!P\"`"__RW@F0,,Z)QG
M@("9W[K_$00E""``"`"_WP``O-\(`.`#$`"]9[#NO6<X$;S_`@`</#`1M_\M
MX)D#^!"P_R6`@`!($;__V.><9Q@1M/\($;+_)9"@``"#E]]0@(3?4("9WT`1
MOO\H$;;_(!&U_Q`1L_]0:(1D`!&Q_T0_.6<``.+>Z!"B_Y;]$00E""``+P`%
M)#B"F=\E(``""?@@`R6@0``.`$`0*(*9WU"`A-\E*``"4("9WTQ$.6?+_A$$
M8&B$9.@0H]\``.+>7P!B$$@1O]_0@IG?"?@@`R4((``E(``"4("3WU"`E=\)
M^"`#4("6WZ"!F=\E($`"<&AE9N@`LF<`B`(`>&BU9H!HUF9P:'-F"?@@`P$`
M,28E\$``4(""W]AG0F0``*+_$`"B9P@`HO_>_\`34("$WP``PH,!`$!0``"^
MWPP`@!)0@YG?)2C``PGX(`,E((`""`!`%"B"F=^@@9G?)2A@`@GX(`,E(```
M[_\`$"7P0``H@IG?"?@@`R4@P`,`$`(`__]#)"\`!B0M&,,#``!D@"@`AA#_
M_T4D(1`B`@`00BB__T`0((&9WR50``(E2*`")4#``R4XP`(`$`8D`0`%)`GX
M(`,E($`""`"EWV"`F=]$!A$$)2!``M__0!0P`**/`(`#-`#P0C#<_T,4H(&9
MWZB!F=\!``4D"?@@`R4@0`+6_T`4H(&9WU"`A-\E*$`"4("9WTQ$.6=Q_A$$
M8&B$9!"#F=\)^"`#)2!``J+_`!`E@$``)1"@`-'_`!```&"@)1```D`1OM\X
M$;S?,!&WWR@1MM\@$;7?&!&TWQ`1L]\($;+?`!&QW_@0L-\(`.`#4!&]9R40
M@``O``4D``"#@`,`8!0E""``"`#@`R4((`#Z_V44`0"$9/C_`!`E$(``X/^]
M9Q``O/\"`!P\&`"__RW@F0,(`+#_!`"`$%3EG&<``(*`"P!`%"6`@`!0@(3?
M$(.9W]AGA&0)^"`#)0@@`!@`O]\0`+S?"`"PWP@`X`,@`+UG*(*9WPGX(`,E
M""``__]&9"\``B0M,`8"*Q@&`B,`8!`E""````##@/O_8E#__\9D+P`")"L8
M!@(<`&`0)0@@````PX`7`&(4___$9"\``B3__\9D*Q@&`@4`8%`O,-````##
M@/O_8E#__\9D+S#0``(`PV0!$&,LW/]@$"40```E*``".("0WP`0!R3`@9G?
M`0#&9`GX(`,(M`1FT_\`$`BT`F;C_P`0)3"``.?_!A8O``(D```#@@0`8A00
M@YG?4("$W\?_`!#89X1D4("$W\3_`!!X:(1D@/^]9R(`!B1P`+S_`@`</"4@
MH`-@`+7_+>"9`W@`O_]H`+;_*.2<9U@`M/]0`+/_`(.5WVB`A=\(@YG?2`"R
M_T``L?\X`+#_``"BWA"FI610@)#?4("3WU"`E-]0@)+?*`"B_PGX(`.L/Q!F
M4("$WU"`EM\ER``"4("1W[W\$02(:(1D4("$WR7(``)$/S%FN/P1!)AHA&10
M@(3?)<@``K3\$02@:(1D4("$WR7(``*P_!$$L&B$9"7(``*M_!$$N&AD9E"`
MA-\ER``"J?P1!,AHA&0ER``"IOP1!%!HA&8ER``"H_P1!-AH1&8ER``"H/P1
M!.AHQ&90@(3?)<@``IS\$03X:(1D4("$WR7(``)0@)#?8&B$9);\$01,1!!F
M4("$WR7((`)X_!$$"&F$9`0`0!`ER``")2A``+7]$03H:,1F4("$WR7((`)O
M_!$$(&F$9`4`0!`E*$``4("$WR7(``*K_1$$.&F$9%"`A-\ER"`"9?P1!$AI
MA&10:(1F"`!`%"4H0`!0@(3?)<@@`E[\$018:81D$0!`$"4H0`#8:$1F)<@`
M`IK]$00E""``4("%W[AH9&8ER``"E?T1!(!II60H`*/?``"BW@X`8A!X`+_?
MT(*9WPGX(`,E""``4("%WPH`!B01`*1G8(&9WPGX(`-P::5D[O]`5%"`A=_G
M_P`0&P"E9W``O-]H`+;?8`"UWU@`M-]0`+/?2`"RWT``L=\X`+#?"`#@`X``
MO6?@_[UG__\")!``O/\"`!P\"`"P_RW@F0,8`+__^.&<9SB`D-]`L`..#P!B
M%!@`O]]0@(3?4("9WT0_.6<G_!$$V&B$9`8`0!`E&`````!"@`0`0%!`L`.N
M,`!"."L8`@!`L`.N&`"_WT"P`HX0`+S?"`"PWP@`X`,@`+UG\/^]9P``O/\"
M`!P\"`"__RW@F0-\X9QGR(*9WPGX(`,E""``,(.9WPGX(`,E($```0!`5```
M0MP(`+_?``"\WP@`X`,0`+UGT/^]9R``O/\"`!P\&`"S_RW@F0,(`+'_)8B`
M`"@`O_\TX9QG$`"R_P``L/]0@)/?4("9WT0_.6?W^Q$$B&ED9B4@8`(%`$`0
M)2@@`B6`0````$*`#`!`%%B#F=^(:81D4("9WR@`O]\@`+S?&`"SWQ``LM\(
M`+'?3$0Y9P``L-\G_0`0,`"]9PGX(`,E(``"&P!`%"@`O]\H@IG?"?@@`R4@
M(`(H@IG?)2```@GX(`,ED$``6(*9WRT00@()^"`#`@!$9%"`B=\!``4D4("'
MWR50``(E0"`"((&9WR600``E($``__\&)'!H*64)^"`#@&CG9"4H0`+9_P`0
MB&ED9B``O-\8`+/?$`"RWP@`L=\``+#?"`#@`S``O6?@_[UG$`"\_P(`'#P8
M`+__+>"9`P@`L?\``+#_&."<9XB`F=^G_A$$)8"``)"`F=^9_A$$)2!``)B`
MF=]X_Q$$)8A``!4`0!`8`+_?%```4A``O-\```*"$0!`4!``O-]0@(7?)2`@
M`EB#F=\)^"`#F&FE9`D`(A88`+_?4("9WR4@``(0`+S?"`"QWP``L-\003EG
M#/P`$"``O6<0`+S?"`"QWP``L-\(`.`#(`"]9_#_O6<``+S_`@`</`@`O_\M
MX)D#:-^<9UB"F=\)^"`#@``$)$5G!#P!(X1D*`!`_#``0/P``$3\YW<$)'@`
M0*QX)`0`B:N$9`@`1/Q=3`0\?VZ$9'@@!``0`$3\,A`$/'94A&08`$3\/0P$
M/!\NA&0X(00`(`!$_`@`O]\``+S?"`#@`Q``O6?`_[UG^!`&`#``O/\"`!P\
M&`"R_R60H``0`+'_+>"9`R6(P``(`+#_)8"``#@`O_\H`+3_(`"S_R@`@]PM
M$$,`/!`"`#X0`@`K&$,`!`!@$.#>G&<P`(/<`0!C9#``@_PP``/>.``39G@`
M!(XH``+^>A<1`"T08@`7`(`0,``"_D```B0C$$0`*AA1``(`8!`E,"`")3!`
M``B#F=\E*$`"+2!D`@GX(`,EH,``>``"CD```R0A$%0`$0!#%'@``JY0@)G?
M)2```B.(-`+P(SEG9_01!"V05`)0@)3?\".49D``(BH/`$`0"(.9WR4P(`(E
M*$`""?@@`R4@8`)X`!&N.`"_WS``O-\H`+3?(`"SWQ@`LM\0`+'?"`"PWP@`
MX`-``+UG)2A``D``!B0E(&`"0`!29@GX(`/`_S$F)<B``DOT$00E(``"YO\`
M$$``(BJP_[UG0`"\_P(`'#PX`+?_.`"W9#``MO\MX)D#(`"T_Q``LO^0W9QG
M"`"Q_R6(@`"`_P0D``"P_R6`H`!(`+__*`"U_Q@`L_\H`**4*`"SW%"`EM\P
M`+7<^(&9WP"2`@#__T(P`A("`/`CUF8E$$("__]2,#``HI0`H@(`__]",`(2
M`@`E$(("__]4,/H0$P`_`$(P)1A```$`0B0M&.,"``!DH#D`0RAA`&`4+2#B
M`D``!B0E*```"?@@`R,PP@`ER,`"%O01!"4@``+X@9G?.``&)"4H```E(.`"
M"?@@`R4((``Z%A4`<@`4IB4@``(ER,`"=@`2IG```J(ZK!4`.A83`#J<$P!Q
M`!6B=``"H@/T$01U`!.B)2```@```MX8@YG?.A8"````(J(```+>.A0"``$`
M(J(```+>.A("``(`(J(```+>`P`BH@@``MXZ%@(`!``BH@@``MXZ%`(`!0`B
MH@@``MXZ$@(`!@`BH@@``MX'`"*B$``"WCH6`@`(`"*B$``"WCH4`@`)`"*B
M$``"WCH2`@`*`"*B$``"W@L`(J(8``+>.A8"``P`(J(8``+>.A0"``T`(J(8
M``+>.A("``X`(J(8``+>#P`BHB```MXZ%@(`$``BHB```MXZ%`(`$0`BHB``
M`MXZ$@(`$@`BHB```MX)^"`#$P`BHD@`O]]``+S?.`"WWS``MM\H`+7?(`"T
MWQ@`L]\0`++?"`"QWP``L-\(`.`#4`"]9S@`!B0E*```J/\`$",PP@`0@+UG
M:($#-#``!B38?[S_`@`</-!_M_\MX)D#Z'^__\A_MO]0VYQGP'^U_R6H@`"X
M?[3_`(.7WYA_L/___Q`\X'^^_[!_L_^H?[+_H'^Q_Q#^O6<``.+>$`"D9SB`
MA=\(@YG?+1AD`%"`EM]0@)3?``!B_'"!`C00L*5D+1!$`$0_UF8M@%``4(""
MW]A^!&;0?@#^N&E"9,!^`OY0@(+?V&="9`GX(`/(?@+^4&B$9E"`@M\ER,`"
MN'X`_N!I0F2H?@+^4(""W^AI0F19^A$$L'X"_A8`0!"@@)G?)8!`````0H`2
M`$`0)0@@`*B`F=]*_A$$)2```A"#F=\)^"`#)2```B6`0``0`*-G:($"-"T0
M0P```$/<``#BWN,!8A`E$``"T(*9WPGX(`,E""``*/X1!"4((``;`$`4)8!`
M`/__$3QP@0(T$`"C9ZA^,68M$$,`+8A1````)-X$`(`4)<C``E"`D-\/```0
ML&D09C#Z$00E""```P!`%"4@0`#U_P`0"``Q9@``0H#R_T!0"``Q9A"#F=\)
M^"`#)0@@`/?_0!`E@$``*(*9WR4@``()^"`#4("3WUB"F=_X:7-F>"`"``GX
M(`,!`(1D)9!``"6(0`````B"7P``%2"!F=]0@)/?__\1/'"!`C00`*-GV'XQ
M9BT00P!D0'-F+8A1````,-X1```2)<C``@GZ$00E(``"6@!`$"6`0````$*`
M]_]`4`@`,68ER&`"2?H1!"4@``+R_T`0"``Q9A"#F=\)^"`#)2```B6`0`!0
M@)[?__\1/'"!`C00`*-GP'XQ9BT00P!D0-YG+8A1``@``!8H@IG?```SW@4`
M8!(E""````!B@D``0!0ER,`#*(*9WPGX(`,E(``"*(*9WR4@0`()^"`#)8A`
M`%B"F=\M("("`"`$``0$GB0)^"`#)2#``R580`)0@(K?4("2WR5```+__P8D
M4("'WP$`!20E($``((&9WR6(0`"8:4IE>&A)9@GX(`,`:N=D\(&9W\`!!20)
M^"`#)2`@`O__`R0H`&(4X(&9WPGX(`,E""````!)C!$``B0C`"(1$`"C9RB#
M@M\E0"`"`0`%)%"`AM\``*?><(&9WP``1-P)^"`#$&K&9&W_`!`E@```)2`@
M`O\`"#$E.&`"__\&)`$`!20!`!!F"?@@`P(`,6:7_P`0```(@I__`!`(`#%F
M\OD1!"4@8`*V_T!0"``Q9A"#F=\)^"`#)2!@`B6`0`"P_P`0"``Q9A``HV?_
M_Q`\6("9WW"!`C0E("`""'\%9BT00P"L`A$$+2A%``P`0!`EF$``*(."WR5`
M(`(!``4D4("&WP``I]YP@9G?``!$W`GX(`-0:L9DT_\`$"4((``0`*-G<($"
M-"T00P``0`,D+8!0`"A_`HX`\$(P[O]#%"B#@M\X?P..R(*9WPGX(`,8`*/_
M&`"CWP`0`@#F_V(4*(."WRA_`H[``0,D_P%",.'_0Q0H@X+?6(*9WPGX(`,E
M(,`#4("$WR7(P`(E@$``;OD1!*AJA&2!`$`4)2!`````MMXH@IG?"?@@`R4@
MP`(`$`(`)?!```0`0B@B`$`4F("9WU"`A=_\_\1G4(.9WRT@Q`()^"`#L&JE
M9!H`0!28@)G?!``")`8`PA/[_]XG+P`")"WPW@(``,.#$@!B%"4((``(`+7>
M#@"@$BB"F=\)^"`#)2"@`@0`0RP*`&`4F("9WU"`A=_\_T)D4(.9WRT@H@()
M^"`#N&JE9`$`0%`EL*`"F("9WPG]$00E""``IP!`%%"`A=\8@IG?)2@```GX
M(`,E(,`"H`!`$"6H0`!X@IG?`@`&).[_!20E($``__\3/`GX(`/X?W9F$`"C
M9T"#F=]P@0(T!@`&)"4@H`(M$$,`+;!6``GX(`,E*,`"$`"C9W"!`C0M$$,`
M+1!3`/A_0Y!!`&`4>(*9W_E_0Y!#``0D/@!D%"4P``#Z?T6000`$)#L`I!0E
M*```^W]$D#@`@Q0E""``_']$D$@``R0U`(-4)2"@`OU_0Y!%``(D,0!B5"4@
MH`("``8DQO\%)`GX(`,E(*`"0(.9WRD`!B0E*,`""?@@`R4@H`)0@(O?)5#`
M`J!K:V50@(??>&A)9B5`(`(@@9G?__\&)`$`!20E(``""?@@`\!JYV08@YG?
M"?@@`R4@(`)0@)G?)2@``DQ$.6<S^A$$4&B$9JB`F=_H_!$$)2```J+^`!`0
M`*-G$(.9WPGX(`,``+;>L("9WR4@P`(V^Q$$)2A``'G_0!0EL$``=_\`$```
MMMXE,```)2@``"4@H`()^"`#__\3/+B`F=]&_1$$^']^9A``HV<EL$``<($"
M-"T00P`M\%X`0(.9WP"`!C0E*,`#"?@@`R4@H`(`,`(`+P#`',"`F=\X@9G?
M)2"@`N!_<V8)^"`#)?```!``HV?(@)G?<($"-"4HP`+__Q8\+1!#`"VH4P`H
M_W-FH/T1!"4@H`)0@(??<($"-!``HV<M$$,`^&GG9"V84P`M$+X"((&9WR4@
M8`+__P8D`0`%)!@`I_\``$B0`0#>9PGX(`,"`'-F%``#)/3_PQ<8`*??$`"C
M9W"!`C10@(O?"'_*9BT00P`M$%8`H&MK93!_0*!P@0(T+1!#`)W_`!`M4$H`
M)2C``RK]$00E(,`"Q_\`$$"#F=]0@(7?__\>)%"`A-]0@)G?4("5WU"`EM^`
M::5D3$0Y9]'Y$038:(1D<(*9WPGX(`/@:M9F4("'WZ!KJV8@@9G?>&A)9B5`
M(`(E4$``__\&)`$`!20E(``"H&NU9GAH4F8)^"`#T&KG9/"!F=_``04D"?@@
M`R4@``*!_\(7X(&9WPGX(`,E""``$0`#)```0HQ[_T,4<(*9WPGX(`,E""``
M((&9WP$`:R8E2$`")4`@`@``M?\E4$``)3C``O__!B0!``4D)2```@GX(`,E
MF&`!YO\`$/"!F=_P`;UGZ'^_W^!_OM_8?[S?T'^WW\A_MM_`?[7?N'^TW[!_
ML]^H?[+?H'^QWYA_L-\(`.`#\'^]9X#_O6=H`+S_`@`</"@`L/\MX)D#>`"_
M_S@`LO]LTIQG,`"Q_W``OO_`@I#?2(&9WV``M_]8`+;_4`"U_T@`M/]``+/_
M```$C@GX(`-0@)+?```$CDB!F=]$/U)F"?@@`R6(0`!0@(3?)<A``K@`(Y*X
M:(1D-O@1!+D`0Z`'`$`0,0`#)```1(`%`(,4T("9WP$`0H`%`$`02(&9W]"`
MF=]H^Q$$)0@@`$B!F=\)^"`#```$CE"`A=\+``<D4(*9WP$`!B0E($``"?@@
M`_AJI612`$!4$`!"W$B!F=\)^"`#```$CE"`A=\#``<D4(*9WP$`!B0E($``
M"?@@`P!KI623`$`4)8A``$B!F=\)^"`#```$CE"`A=\#``<D4(*9WP$`!B0E
M($``"?@@`Q!KI601`$`0)8A``%"`A-\ER$`"`_@1!&!HA&0```2.2(&9WYD`
M0!`EF$``"?@@`R4((``0`"/>)3!@`IB"F=\E($``"?@@`P``9=Q(@9G?"?@@
M`P``!(X```2.2(&9WPGX(`,EB$``4("%WP$`!B00@IG?)2!```GX(`,8:Z5D
M4("&WR4@(`*8@IG?)2A```GX(`,P:\9D```$CDB!F=\)^"`#.("0WU"`A-\E
MR$`")8@``KD`0*#:]Q$$4&B$9'X`0!3PLP+^.(""W]B`F=]'_1$$`+1$W'@`
M0!3PLP+^4("$WPB"F=\)^"`#.&N$9"``$3P!`!8D.("5WP`$'B0X@)??``0Q
M)B@`5-PEF*`"___")@``!(X(`*+_^+.BCBH0P@(,`$`0___&)DB!F=\)^"`#
M$`"FKQ``IH\E*(`"F(&9WR4X```)^"`#)2!```@`0!0E*$``^+-BC@@`H]__
M_T(DDO]#%$B!F=\G```0`0`1)`"TY-[X$!8`+1""````I-P``$C<#`""C"00
M40`)`%X42(&9WQ``A=Q0@YG?"?@@`R4@``'L_T`4^+-BCM?_`!`!`-8F```$
MCA``J/\)^"`#&`"E_Q@`I=\"``<DD(*9WR4P```E($``"?@@`P``I=P0`*C?
M[/\`$"4H0`!(@9G?"?@@`P$`,2;X@IG?)2B``@GX(`,E($``^+-BCBH0(@+V
M_T`4```$CF3_`!!(@9G?2(&9WPGX(`,```2.$``CWE"`AM^8@IG?)2!`````
M9=P)^"`#"&O&9!``(MX``$+<#`!"C((5`@`!`$(P7_]`$$B!F=\)^"`#```$
MCA``(][(@9G?)2!```GX(`,``&7<5O\`$$B!F=\)^"`#)0@@`#B`@M]0@)G?
M`+1#W!``(MX00SEG``!EW%#X$00``$3<9?\`$"4((`#PLR;>P`$%)/"!F=\E
M(,``"?@@`P@`IO\E.$``$0`")`L`XA`!`.(D`@!"+`@`0!0(`*;?.(""WU"`
MA-\(@IG?`+1"W&!KA&0)^"`#``!%W'@`O]]P`+[?:`"\WV``M]]8`+;?4`"U
MWT@`M-]``+/?.`"RWS``L=\H`+#?"`#@`X``O6?`_[UG,`"\_P(`'#P(`+'_
M+>"9`P``L/\0`++_)9````#.G&<H`+7_):C``"``M/\EH*``^("0WP"!D=\(
M@9G?&`"S_R68@``X`+__3.\1!"^(,`+[B!$`"P!15@``&=XX`+_?,`"\WR@`
MM=\@`+3?&`"SWQ``LM\(`+'?``"PWP@`X`-``+UG)3"@`B4H@`(E(&`"`0!2
M9@GX(`,(`!!F[?\`$"4((``(`.`#)0@@`/#_O6<``+S_`@`</`@`O_\MX)D#
M4,V<9TB`@M^`@IG?"?@@`P``1]P(`+_?``"\WP@`X`,0`+UG)0@@`"4((`#P
M_[UG)3"@`"4H@````+S_`@`</`@`O_\MX)D#$,V<9U"!F=\)^"`#`P`$)`@`
MO]\``+S?"`#@`Q``O6<E""``\/^]9R4PH``E*(````"\_P(`'#P(`+__+>"9
M`]#,G&=`@9G?"?@@`P,`!"0(`+_?``"\WP@`X`,0`+UG)0@@`!"`F=\E>.`#
M"?@@`VL`&&00@)G?)7C@`PGX(`-J`!AD$("9WR5XX`,)^"`#:``89!"`F=\E
M>.`#"?@@`V8`&&00@)G?)7C@`PGX(`-D`!AD$("9WR5XX`,)^"`#8P`89!"`
MF=\E>.`#"?@@`V(`&&00@)G?)7C@`PGX(`-A`!AD$("9WR5XX`,)^"`#7P`8
M9!"`F=\E>.`#"?@@`UT`&&00@)G?)7C@`PGX(`-<`!AD$("9WR5XX`,)^"`#
M6P`89!"`F=\E>.`#"?@@`UH`&&00@)G?)7C@`PGX(`-9`!AD$("9WR5XX`,)
M^"`#5P`89!"`F=\E>.`#"?@@`U8`&&00@)G?)7C@`PGX(`-4`!AD$("9WR5X
MX`,)^"`#4P`89!"`F=\E>.`#"?@@`U(`&&00@)G?)7C@`PGX(`-1`!AD$("9
MWR5XX`,)^"`#4``89!"`F=\E>.`#"?@@`T\`&&00@)G?)7C@`PGX(`-.`!AD
M$("9WR5XX`,)^"`#30`89!"`F=\E>.`#"?@@`TP`&&00@)G?)7C@`PGX(`-+
M`!AD$("9WR5XX`,)^"`#2@`89!"`F=\E>.`#"?@@`T@`&&00@)G?)7C@`PGX
M(`-'`!AD$("9WR5XX`,)^"`#1@`89!"`F=\E>.`#"?@@`T4`&&00@)G?)7C@
M`PGX(`-$`!AD$("9WR5XX`,)^"`#0P`89!"`F=\E>.`#"?@@`T(`&&00@)G?
M)7C@`PGX(`-!`!AD$("9WR5XX`,)^"`#0``89!"`F=\E>.`#"?@@`S\`&&00
M@)G?)7C@`PGX(`,^`!AD$("9WR5XX`,)^"`#/``89!"`F=\E>.`#"?@@`SL`
M&&00@)G?)7C@`PGX(`,Z`!AD$("9WR5XX`,)^"`#.0`89!"`F=\E>.`#"?@@
M`S@`&&00@)G?)7C@`PGX(`,W`!AD$("9WR5XX`,)^"`#-@`89!"`F=\E>.`#
M"?@@`S4`&&00@)G?)7C@`PGX(`,T`!AD$("9WR5XX`,)^"`#,P`89!"`F=\E
M>.`#"?@@`S$`&&00@)G?)7C@`PGX(`,P`!AD$("9WR5XX`,)^"`#+P`89!"`
MF=\E>.`#"?@@`RX`&&00@)G?)7C@`PGX(`,L`!AD$("9WR5XX`,)^"`#*@`8
M9!"`F=\E>.`#"?@@`RD`&&00@)G?)7C@`PGX(`,H`!AD$("9WR5XX`,)^"`#
M)P`89!"`F=\E>.`#"?@@`R8`&&00@)G?)7C@`PGX(`,E`!AD$("9WR5XX`,)
M^"`#)``89`````````````````````#P_[UG``"\_P(`'#PMX)D#"`"__\#(
MG&<(`+_?``"\WP@`X`,0`+UG```````````!``(``````"X`````````+BX`
M```````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``
M````+W!R;V,O)6DO)7,``````%!!4E]414U0``````````!005)?4%)/1TY!
M344`````.@`````````O`````````"5S)7,E<P``4$523#5,24(`````````
M`%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'
M`````````%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'````````
M``!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%2
M7T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#3$5!
M3CT````````Q`````````$Q$7TQ)0E)!4EE?4$%42`!P87(M`````"UE````
M````+2T```````!365-414T``"]T;7``````5$U01$E2``!414U01$E2`%1%
M35``````5$U0``````!54T52`````%5315).04U%```````````E,#)X````
M`"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%!!5$@`````<&%R
M;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````
M)7,E<W1E;7`M)74M)74E<P``````````05)'5@`````8`````````'!E<FP`
M````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U,````%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@
M(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T
M;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T
M;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M
M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`](")<
M;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM
M>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA
M9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK
M7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E
M('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@
M*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O<RP@,"D[
M"G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!
M1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI
M(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S
M("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I
M+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*
M<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP
M86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&EN
M9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE
M(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@
M("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[
M4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG+"`D
M<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H
M)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G
M)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D
M+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P
M87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R
M(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP
M,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@
M/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@
M/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B
M7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%2
M7R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H
M("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE
M;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]
M('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*
M9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M"FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY
M("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@
M/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<
M6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS
M:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C
M:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ
M<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG
M+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D
M92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD
M9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT
M96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@
M)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@
M)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@
M(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M
M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@
M70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E
M<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS
M=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN
M84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q
M=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L
M.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA
M;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$[
M"G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2
M.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T
M97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E
M(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER
M92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<
M5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G
M;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE
M;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L
M("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I
M;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG97-T
M(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H
M+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M
M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO
M<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D
M*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W
M9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG
M4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY0
M05)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@(```````````<&5R;'AS:2YC````````````
M````````+VQI8C8T+VQD+G-O+C$```$;`SL$`0``'P```,!Y__]H!0``D'W_
M_R`!``#LE___6`$``.28__^@`0``3)G__]`!```$FO__"`(``+":__\X`@``
ML)S__X`"``#LG?__P`(``"2@__\``P``?*#__R@#``#\H/__6`,``/2A__^0
M`P``**+__[@#``"`I/__``0``*RD__\@!```V*7__U`$```(J/__D`0``(2H
M___`!```S*C__^@$``#HJ?__,`4``)BJ__^@!0``(*O__\@%``!PK/__"`8`
M`+"N__]0!@``E+?__Z@&````O/__\`8``*B\__\P!P``L+S__U`'``#PO/__
M>`<``#"]__^@!P```````!0``````````7I2``%\'P$<#1T``````#0````<
M````:'S_______]<&@````````!$#L`%4)P$8)\"DP:2")$*D`P#*!H.`-#1
MTM/<WP``1````%0```",EO________@``````````$0.4$2<!$B1$&2?`I8&
ME0B4"I,,D@Y(D!("K`H.`-#1TM/4U=;<WPL`````````+````)P````\E___
M_____V@``````````$0.,$2<!%20!I\"`DP.`-#<WP``````-````,P```!T
ME________[@``````````$0.4$2<!%R1"I`,DP:2"$B?`@*,#@#0T=+3W-\`
M```L````!`$``/27________K```````````1`Z``D2<!%21!I`(2)\"`H@.
M`-#1W-]$````-`$``'"8________``(`````````1`[@`D2<!F"6"I\"G@27
M")4,6)0.DQ"2$I$4D!8#P`$.`-#1TM/4U=;7W-[?```\````?`$``"B:____
M____/`$`````````1`[0($B<!%"4")$.4)4&DPI(D@Q<GP*0$`+L#@#0T=+3
MU-7<WP``/````+P!```DF________S@"`````````$0.8$2<!%"3#)$02)`2
M8)\"E@:5")0*D@X#^`$.`-#1TM/4U=;<WR0```#\`0``')W_______]8````
M``````!$#A!$G`1(GP("2`X`W-\L````)`(``$R=________@```````````
M1`X@1)P$4)`&GP(":`X`T-S?```````T````5`(``)R=________^```````
M````1`[@0$2<!%R2!I\"D`J1"`+4#@#0T=+<WP```````"0```",`@``7)[_
M______\T``````````!$#A!$G`1(GP)D#@#<WP!$````M`(``&B>________
M6`(`````````1`[0(D2<!E"7")`65)\"E`Z2$FB>!)8*E0R3$)$4`P0"#@#0
MT=+3U-76U]S>WP`<````_`(``'B@________+````````````````````"P`
M```<`P``A*#_______\L`0````````!$#B!$G`10GP*0!GP*#@#0W-\+````
M`#P```!,`P``@*'_______\P`@````````!$#H`!2)P$9)4(GP*6!I0*DPQ8
MD@Z1$)`2`^@!#@#0T=+3U-76W-\L````C`,``'"C________?```````````
M1`X@2)P$4)`&GP("8`X`T-S?```````D````O`,``+RC________2```````
M````1`X01)P$2)\">`X`W-\`1````.0#``#<H________QP!`````````$0.
M,$2<!%"3!I$*5)\"D@B0#`)4"M#1TM/<WT@.``L"E`X`T-'2T]S?````````
M-````"P$``"PI/_______[```````````$0.($2<!%2?`I$&D`@">`K0T=S?
M2`X`"U0.`-#1W-\T````9`0``%!T________8`(`````````1`Y01)P$?)\"
MD`R3!I((D0H#``(*#@#0T=+3W-\+`"0```"<!```\*3_______^(````````
M``!$#A!$G`1(GP(">`X`W-\\````Q`0``%"E________4`$`````````1`Y`
M2)P$2)(*3)$,2)`.4)\"E`:3"`+L"@X`T-'2T]3<WPL`````1`````0%``!@
MIO_______T`"`````````$0.4$2<!$B7!ER6")0,DA"1$DR0%%"?`I4*DPX#
MZ`$*#@#0T=+3U-76U]S?"P``5````$P%``!8J/_______^0(`````````$0.
M\/\!3)P&7)<(GP*6"I4,4)0.D!98#N"#`IX$DQ"2$I$4`UP(#O#_`70.`-#1
MTM/4U=;7W-[?`````````$0```"D!0``Y+#_______]L!`````````!$#H`!
M1)P&8)`6GP*2$I$4G@1<EPB6"I4,E`Z3$`,H!`X`T-'2T]35UM?<WM\``#P`
M``#L!0``"+7_______^H``````````!$#D!$G`14D0Z0$)(,3)4&2)0(5),*
M2)\"?`H.`-#1TM/4U=S?"P`<````+`8``'"U________"```````````````
M`````"0```!,!@``6+7_______\X``````````!$#A!$G`1(GP)H#@#<WP`D
M````=`8``'"U________/```````````1`X03)P$2)\"9`X`W-\`)````)P&
M``"(M?_______SP``````````$0.$$R<!$B?`F0.`-S?````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-0C````
M````9",`````````````````````````````.&D```````#`:0```````,AI
M````````T&D```````#8:0``````````````````_____P``````````````
M`*AK````````````````````````````````````````````````````````
M````@"`@````````8&(````````(8P```````````@``````:+`!``````#`
MLP$`````````````````D&,```````!08P```````````0``````A$8`````
M``#T70```````%Q'````````#$L```````#@2@```````&A.````````Y$X`
M```````L3P```````(A(````````^%````````"`40```````-!2````````
M.$P````````050```````!!C````````4+`!``````!(4````````/"O`0``
M````^*\!``````#@'P````````````````````````````"`9P```````'!G
M````````8&<```````!09P```````$!G````````,&<````````@9P``````
M````````````$&<```````````````````!G````````\&8```````#@9@``
M`````-!F``````````````````#`9@```````+!F````````H&8```````"0
M9@```````(!F````````<&8```````!@9@```````%!F````````0&8`````
M```P9@``````````````````(&8````````09@````````!F````````\&4`
M``````#@90```````-!E````````P&4```````"P90```````*!E````````
MD&4```````"`90``````````````````<&4```````!@90```````%!E````
M````0&4````````P90```````"!E````````$&4`````````90```````/!D
M````````X&0```````#09```````````````````P&0```````"P9```````
M````````````H&0```````"09````````(!D````````<&0```````!@9```
M````````````````4&0``````````````````$!D````````,&0````````@
M9````````!!D````````````````````9```````````````````\&,`````
M`````````````.!C````````T&,```````#`LP$``````$=#0SH@*$=.52D@
M,3`N,RXQ(#(P,C$P-3$P("A!3U-#($]3+"!#;W)E*0``\",`````#Y#X____
M``````````#``@``'0```!\```!,/@````!_D/C___\``````````%`````=
M````'P```$0_``````&0^/___P``````````,````!T````?````K#\`````
M#Y#X____``````````!0````'0```!\```!D0``````#D/C___\`````````
M```!```=````'P```!!!`````/_0^/___P``````````8`$``!T````?````
M$$,`````/Y#X____``````````!0$```'0```!\```!,1`````!_D/C___\`
M`````````&`````=````'P```(1&``````"0^/___P``````````$````!T`
M```?````W$8``````9#X____```````````@````'0```!\```!<1P`````'
MD/C___\``````````&`@```=````'P```%1(``````"0^/___P``````````
M$````!T````?````B$@`````_]#X____``````````!0$0``'0```!\```#@
M2@`````````````````````````````=````'P````Q+``````&0^/___P``
M````````(````!T````?````.$P`````?Y#X____``````````"`````'0``
M`!\```!H3@`````!D/C___\``````````"`````=````'P```.1.``````"0
M^/___P``````````$````!T````?````+$\`````#Y#X____```````````P
M````'0```!\```!(4``````#D/C___\``````````"`````=````'P```"`@
M``````^0^/___P``````````4````!T````?````^%```````)#X____````
M```````0````'0```!\```"`40`````?D/C___\``````````$`````=````
M'P```-!2`````/^0^/___P``````````4````!T````?````$%4`````_]#X
M____``````````#@@0``'0```!\```#T70````#_T/C___\``````````(``
M```=````'P```&!B`````#^0^/___P``````````0````!T````?````"&,`
M````````````````````````````'0```!\````08P``````D/C___\`````
M`````!`````=````'P```%!C``````"0^/___P``````````$````!T````?
M````D&,``````)#X____```````````0````'0```!\```!!#P```&=N=0`!
M!P````0!`"YS:'-T<G1A8@`N34E04RYA8FEF;&%G<P`N34E04RYO<'1I;VYS
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YD>6YA;6EC`"YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N
M7W(`+G)E;"YD>6X`+FEN:70`+G1E>'0`+DU)4%,N<W1U8G,`+F9I;FD`+G)O
M9&%T80`N:6YT97)P`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R
M<F%Y`"YF:6YI7V%R<F%Y`"YD871A`"YR;&1?;6%P`"YG;W0`+G-D871A`"YB
M<W,`+F-O;6UE;G0`+G!D<@`N9VYU+F%T=')I8G5T97,`````````````````
M````````````````````````````````````````````````````````````
M``````````````L````J``!P`@````````"H`@```````*@"````````&```
M``````````````````@`````````&``````````:````#0``<`(```@`````
MP`(```````#``@```````.`!```````````````````(``````````$`````
M````*`````<````"`````````*`$````````H`0````````D````````````
M````````!````````````````````#L````'`````@````````#$!```````
M`,0$````````(`````````````````````0```````````````````!)````
M!@````(`````````Z`0```````#H!````````)`"````````"``````````(
M`````````!``````````4@````4````"`````````'@'````````>`<`````
M````!0````````<`````````"``````````$`````````%@````+`````@``
M``````!X#````````'@,````````(`H````````(`````@````@`````````
M&`````````!@`````P````(`````````F!8```````"8%@```````#D%````
M```````````````!````````````````````:````/___V\"`````````-(;
M````````TAL```````#8``````````<``````````@`````````"````````
M`'4```#^__]O`@````````"P'````````+`<````````H``````````(````
M`P````@```````````````````"$````"0````(`````````4!T```````!0
M'0```````*``````````!P`````````(`````````!``````````C0````$`
M```&`````````.`?````````X!\```````!`````````````````````!```
M`````````````````),````!````!@`````````@(````````"`@````````
ML$,``````````````````!````````````````````"9`````0````8`````
M````T&,```````#08P```````-`#```````````````````(````````````
M````````I0````$````&`````````*!G````````H&<````````H````````
M````````````!````````````````````*L````!`````@````````#09P``
M`````-!G````````@#X``````````````````!````````````````````"S
M`````0````(`````````4*8```````!0I@````````\`````````````````
M```!````````````````````NP````$````"`````````&"F````````8*8`
M```````$`0``````````````````!````````````````````,D````!````
M`@````````!HIP```````&BG````````Q`8```````````````````@`````
M``````````````#3````#@````,`````````\*\!``````#PKP````````@`
M```````````````````(``````````@`````````WP````\````#````````
M`/BO`0``````^*\````````(````````````````````"``````````(````
M`````.L````!`````P``````````L`$```````"P````````8```````````
M`````````!````````````````````#Q`````0````,`````````8+`!````
M``!@L`````````@````````````````````(````````````````````^@``
M``$````#```0`````'"P`0``````<+````````!0`P``````````````````
M$``````````(`````````/\````!`````P``$`````#`LP$``````,"S````
M````"`````````````````````@````````````````````&`0``"`````,`
M````````T+,!``````#(LP```````$`0```````````````````0````````
M````````````"P$```$````P````````````````````R+,````````K````
M`````````````````0`````````!`````````!0!```!````````````````
M`````````/2S````````X`,```````````````````0`````````````````
M```9`0``]?__;P````````````````````#4MP```````!``````````````
M```````!`````````````````````0````,`````````````````````````
HY+<````````I`0```````````````````0``````````````````````
